@@ -12,7 +12,7 @@ __all__ = (
     'EUI48', 'EUI60', 'EUI64',
     'parse',
 )
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
 
 _HEX_DIGITS = "0123456789ABCDEFabcdef"
@@ -24,9 +24,15 @@ def _name(obj):
 
 def _value_error(value, error, *classes):
     class_names = [cls.__name__ for cls in classes]
-    if len(class_names) > 1:
+    number_of_classes = len(classes)
+    if number_of_classes < 2:
+        class_description = class_names[0]
+    elif number_of_classes == 2:
+        class_description = ' or '.join(class_names)
+    else:
         class_names[-1] = 'or ' + class_names[-1]
-    return ValueError(repr(value) + ' ' + error + ' ' + ', '.join(class_names))
+        class_description = ', '.join(class_names)
+    return ValueError(repr(value) + ' ' + error + ' ' + class_description)
 
 
 class HWAddress:
@@ -323,15 +329,18 @@ def parse(string, *classes):
     Raises:
         ValueError: If the string could not be parsed as any of the
             given classes.
+        TypeError: If the string is not actually a string.
     """
+    if not isinstance(string, str):
+        return TypeError
     if not classes:
         return None
     address, cls = _parse(string, *classes)
     return cls(address)
 
 
-def _parse(input, *classes):
-    length = len(input)
+def _parse(string, *classes):
+    length = len(string)
     if length < 1:
         raise ValueError('hardware address cannot be an empty string')
     candidates = {}
@@ -344,7 +353,7 @@ def _parse(input, *classes):
     start = 0
     end = len(candidates)
     for index in range(length):
-        character = input[index]
+        character = string[index]
         if character in _HEX_DIGITS:
             address <<= 4
             address += int(character, 16)
@@ -354,7 +363,7 @@ def _parse(input, *classes):
         while start < end and candidates[end - 1][0][index] > character:
             end -= 1
         if start >= end:
-            raise _value_error(input, 'cannot be parsed as', *classes)
+            raise _value_error(string, 'cannot be parsed as', *classes)
     _, cls = candidates[start]
     offset = (4 - cls.size) & 3
     address >>= offset
